#
# spec file for package asco
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           asco
Version:        0.4.11
Release:        2.1
Summary:        A SPICE Circuit Optimizer
License:        GPL-2.0-only
Group:          Productivity/Scientific/Electronics
URL:            http://asco.sourceforge.net/
Source0:        http://downloads.sourceforge.net/asco/ASCO-%{version}.tar.gz
# PATCH-FIX-OPENSUSE asco_unbuffered.patch -- patch from QUCS team
Patch0:         asco_unbuffered.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++

%description
ASCO brings circuit optimization capabilities to existing SPICE
simulators using a parallel differential evolution (DE) optimization
algorithm. Currently, out-of-the-box support for Eldo, HSPICE, LTspice,
Spectre, Qucs and ngspice exist.

%package        doc
Summary:        Documentation for ASCO
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
ASCO brings circuit optimization capabilities to existing SPICE
simulators using a parallel differential evolution (DE) optimization
algorithm. Currently, out-of-the-box support for Eldo, HSPICE, LTspice,
Spectre, Qucs and ngspice exist.

This package provides documentation for ASCO in PDF format.

%prep
%autosetup -n ASCO-%{version} -p1
tar -zxf Autotools.tar.gz

%build
# workaround for GCC10 build failure
export CFLAGS="%{optflags} -fcommon"
export CXXFLAGS="$CFLAGS"
autoreconf -fi
%configure
%make_build

%install
%make_install
install -Dm 644 doc/ASCO.pdf %{buildroot}/%{_docdir}/%{name}/ASCO.pdf

%files
%license LICENSE
%doc ChangeLog README
%exclude %{_docdir}/%{name}/ASCO.pdf
%{_bindir}/alter
%{_bindir}/asco
%{_bindir}/asco-test
%{_bindir}/log
%{_bindir}/monte
%{_bindir}/postp
%{_bindir}/rosen

%files doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/ASCO.pdf

%changelog
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions
- Trim R/TM signs as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Sat Apr 30 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.4.11
  * Minor improvements to work/warn about changes in simulators
    output format.
  * Improvements in Spectre support.
  * Bug fixes.
- Drop upstream fixed asco-0.4.10-fix-implicit-declaration.patch
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon to allow building against GCC10
* Sun Jun 10 2018 antoine.belvire@opensuse.org
- Update to version 0.4.10:
  * Simulation re-runs are now supported in Spectre during an
    optimization.
  * Minor enhancements in the RF module.
  * Support for the newest MPICH versions.
  * The 'postp' tool is more robust to changes of each SPICE output
    format.
  * Support for the newest versions of MPICH documented.
- Fix implicit declaration error of 'gethostname':
  * Add asco-0.4.10-fix-implicit-declaration.patch.
* Mon Oct  6 2014 dmitry_r@opensuse.org
- Change package license to GPL-2.0 according to source headers
* Wed Oct  1 2014 dmitry_r@opensuse.org
- Initial package, version 0.4.9
- Add asco_unbuffered.patch for QUCS
